@@ -1,11 +1,14 @@
-package Plack::Middleware::Rewrite;
-$Plack::Middleware::Rewrite::VERSION = '1.009';
+use 5.006;
 use strict;
-use parent qw( Plack::Middleware );
+use warnings;
 
+package Plack::Middleware::Rewrite;
+$Plack::Middleware::Rewrite::VERSION = '1.010';
 # ABSTRACT: mod_rewrite for Plack
 
-use Plack::Util::Accessor qw( rules );
+use parent 'Plack::Middleware';
+
+use Plack::Util::Accessor 'rules';
 use Plack::Request ();
 use Plack::Util ();
 
@@ -77,7 +80,7 @@ Plack::Middleware::Rewrite - mod_rewrite for Plack
 
 =head1 VERSION
 
-version 1.009
+version 1.010
 
 =head1 SYNOPSIS
 
